Extra parameter file
=====================

GADMA take an extra parameter file as input. **However one probably do not need them**. Nevertheless, if one is interested, ``extra_params_template`` with all options and their descriptions can be found in ``gadma/cli/`` folder.